==> supplier-center-api-1.0.42-sources.jar: cn/com/duiba/supplier/center/api/dto/SupplyOrdersDto.java <==
package cn.com.duiba.supplier.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by hww on 2018/11/27 10:03 AM.
 */
public class SupplyOrdersDto implements Serializable {

    private static final long serialVersionUID = 1438174435493720984L;
    /** 主键id */
    private Long id;
    /** 采购单主订单单号 */
    private Long supplyOrderNum;
    /** 交易系统主订单号 */
    private String thirdOrderNum;
    /** 分销商id */
    private Long appId;
    /** 供应商标识类型， 1：京东 */
    private Integer supplierType;
    /** 收货人姓名 */
    private String name;
    /** 收货地址 */
    private String address;
    /** 收货人联系电话 */
    private String phone;
    /** 采购单状态 */
    private Integer orderStatus;
    /** 采购单类型 */
    private Integer orderType;
    /** 下单时间 */
    private Date purchaseTime;
    /** 支付时间 */
    private Date payTime;
    /** 完成时间 */
    private Date finishTime;
    /** 错误类型 */
    private Integer failType;
    /** 错误原因 */
    private String failReason;
    /** 下单ip */
    private String ip;
    /** 是否预占库存 0是 1否 默认0 */
    private Integer submitState;
    /** 采购单总价 */
    private Long totalPrice;
    /** 运费 */
    private Long agreeFreight;
    /** 是否删除 0:否 1:是 默认0 */
    private Integer deleted;
    /** 创建时间 */
    private Date gmtCreate;
    /** 最后更新时间 */
    private Date gmtModified;
    /** 订单商品类型 */
    private String itemType;
    /** 买家留言 */
    private String buyerMsg;

    private String bizNo; //第三方返回的订单号

    private Long agreeTotalPrice;//采购总协议价，实时的

    /**
     * 交易系统子订单号
     */
    private Long ordersItemId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSupplyOrderNum() {
        return supplyOrderNum;
    }

    public void setSupplyOrderNum(Long supplyOrderNum) {
        this.supplyOrderNum = supplyOrderNum;
    }

    public String getThirdOrderNum() {
        return thirdOrderNum;
    }

    public void setThirdOrderNum(String thirdOrderNum) {
        this.thirdOrderNum = thirdOrderNum;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getSupplierType() {
        return supplierType;
    }

    public void setSupplierType(Integer supplierType) {
        this.supplierType = supplierType;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Integer getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(Integer orderStatus) {
        this.orderStatus = orderStatus;
    }

    public Date getPurchaseTime() {
        return purchaseTime;
    }

    public void setPurchaseTime(Date purchaseTime) {
        this.purchaseTime = purchaseTime;
    }

    public Date getPayTime() {
        return payTime;
    }

    public void setPayTime(Date payTime) {
        this.payTime = payTime;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public Integer getFailType() {
        return failType;
    }

    public void setFailType(Integer failType) {
        this.failType = failType;
    }

    public String getFailReason() {
        return failReason;
    }

    public void setFailReason(String failReason) {
        this.failReason = failReason;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Integer getSubmitState() {
        return submitState;
    }

    public void setSubmitState(Integer submitState) {
        this.submitState = submitState;
    }

    public Long getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(Long totalPrice) {
        this.totalPrice = totalPrice;
    }

    public Long getAgreeFreight() {
        return agreeFreight;
    }

    public void setAgreeFreight(Long agreeFreight) {
        this.agreeFreight = agreeFreight;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }

    public String getBuyerMsg() {
        return buyerMsg;
    }

    public void setBuyerMsg(String buyerMsg) {
        this.buyerMsg = buyerMsg;
    }

    public String getBizNo() {
        return bizNo;
    }

    public void setBizNo(String bizNo) {
        this.bizNo = bizNo;
    }

    public Long getAgreeTotalPrice() {
        return agreeTotalPrice;
    }

    public void setAgreeTotalPrice(Long agreeTotalPrice) {
        this.agreeTotalPrice = agreeTotalPrice;
    }

    public Integer getOrderType() {
        return orderType;
    }

    public void setOrderType(Integer orderType) {
        this.orderType = orderType;
    }

    public Long getOrdersItemId() {
        return ordersItemId;
    }

    public void setOrdersItemId(Long ordersItemId) {
        this.ordersItemId = ordersItemId;
    }
}

==> supplier-center-api-2.1.54-20251107.093501-2-sources.jar: cn/com/duiba/supplier/center/api/dto/SupplyOrdersDto.java <==
package cn.com.duiba.supplier.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by hww on 2018/11/27 10:03 AM.
 */
public class SupplyOrdersDto implements Serializable {

    private static final long serialVersionUID = 1438174435493720984L;
    /** 主键id */
    private Long id;
    /** 采购单主订单单号 */
    private Long supplyOrderNum;
    /** 交易系统主订单号 */
    private String thirdOrderNum;
    /** 分销商id */
    private Long appId;
    /** 供应商标识类型， 1：京东 */
    private Integer supplierType;
    /** 收货人姓名 */
    private String name;
    /** 收货地址 */
    private String address;
    /** 收货人联系电话 */
    private String phone;
    /** 采购单状态 */
    private Integer orderStatus;
    /** 采购单类型 */
    private Integer orderType;
    /** 下单时间 */
    private Date purchaseTime;
    /** 支付时间 */
    private Date payTime;
    /** 完成时间 */
    private Date finishTime;
    /** 错误类型 */
    private Integer failType;
    /** 错误原因 */
    private String failReason;
    /** 下单ip */
    private String ip;
    /** 是否预占库存 0是 1否 默认0 */
    private Integer submitState;
    /** 采购单总价 */
    private Long totalPrice;
    /** 运费 */
    private Long agreeFreight;
    /** 是否删除 0:否 1:是 默认0 */
    private Integer deleted;
    /** 创建时间 */
    private Date gmtCreate;
    /** 最后更新时间 */
    private Date gmtModified;
    /** 订单商品类型 */
    private String itemType;
    /** 买家留言 */
    private String buyerMsg;

    private String bizNo; //第三方返回的订单号

    private Long agreeTotalPrice;//采购总协议价，实时的

    /**
     * 交易系统子订单号
     */
    private Long ordersItemId;

    /**
     * 发货状态，0已发完，1未发完
     */
    private Integer deliveryStatus;

    public Integer getDeliveryStatus() {
        return deliveryStatus;
    }

    public void setDeliveryStatus(Integer deliveryStatus) {
        this.deliveryStatus = deliveryStatus;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSupplyOrderNum() {
        return supplyOrderNum;
    }

    public void setSupplyOrderNum(Long supplyOrderNum) {
        this.supplyOrderNum = supplyOrderNum;
    }

    public String getThirdOrderNum() {
        return thirdOrderNum;
    }

    public void setThirdOrderNum(String thirdOrderNum) {
        this.thirdOrderNum = thirdOrderNum;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getSupplierType() {
        return supplierType;
    }

    public void setSupplierType(Integer supplierType) {
        this.supplierType = supplierType;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Integer getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(Integer orderStatus) {
        this.orderStatus = orderStatus;
    }

    public Date getPurchaseTime() {
        return purchaseTime;
    }

    public void setPurchaseTime(Date purchaseTime) {
        this.purchaseTime = purchaseTime;
    }

    public Date getPayTime() {
        return payTime;
    }

    public void setPayTime(Date payTime) {
        this.payTime = payTime;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public Integer getFailType() {
        return failType;
    }

    public void setFailType(Integer failType) {
        this.failType = failType;
    }

    public String getFailReason() {
        return failReason;
    }

    public void setFailReason(String failReason) {
        this.failReason = failReason;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Integer getSubmitState() {
        return submitState;
    }

    public void setSubmitState(Integer submitState) {
        this.submitState = submitState;
    }

    public Long getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(Long totalPrice) {
        this.totalPrice = totalPrice;
    }

    public Long getAgreeFreight() {
        return agreeFreight;
    }

    public void setAgreeFreight(Long agreeFreight) {
        this.agreeFreight = agreeFreight;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }

    public String getBuyerMsg() {
        return buyerMsg;
    }

    public void setBuyerMsg(String buyerMsg) {
        this.buyerMsg = buyerMsg;
    }

    public String getBizNo() {
        return bizNo;
    }

    public void setBizNo(String bizNo) {
        this.bizNo = bizNo;
    }

    public Long getAgreeTotalPrice() {
        return agreeTotalPrice;
    }

    public void setAgreeTotalPrice(Long agreeTotalPrice) {
        this.agreeTotalPrice = agreeTotalPrice;
    }

    public Integer getOrderType() {
        return orderType;
    }

    public void setOrderType(Integer orderType) {
        this.orderType = orderType;
    }

    public Long getOrdersItemId() {
        return ordersItemId;
    }

    public void setOrdersItemId(Long ordersItemId) {
        this.ordersItemId = ordersItemId;
    }
}
